Common Errors
=============

ValueError: <boa.network.NetworkEnv object at 0xXXXXXXXXX>.eoa not defined!
----------------------------------------------------------------------------

This is the most common error you'll run into, and it means you'll need to add an account to your `moccasin.toml`. You can do this by following the :doc:`wallet <wallet>` guide.